@@ -1,6 +1,6 @@
 # ABSTRACT: Get information for different currencies
 package Data::MoneyCurrency;
-$Data::MoneyCurrency::VERSION = '0.26';
+$Data::MoneyCurrency::VERSION = '0.27';
 use strict;
 use warnings;
 use utf8;
@@ -341,7 +341,7 @@ my $rh_currencies_for_country = {
     yt   => ['eur'],
     za   => ['zar'],
     zm   => ['zmk'],
-    zw   => ['zig']        
+    zw   => ['zwg'],
 };
 
 
@@ -373,7 +373,7 @@ Data::MoneyCurrency - Get information for different currencies
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 SYNOPSIS
 
